@@ -10,4 +10,4 @@ set -e
 # The complete set is noted to contain tests that may consume too much memory or have non-portable tests.
 # attrib.lua for example needs some multilib customization (have to compile the stuff in libs/ for each ABI)
 
-cd "${srcdir}"/test && "${LUA}" -e_U=true $(basename ${1})
+cd "${srcdir}"/tests && "${LUA}" -e_U=true $(basename ${1})
